import { FetchMock } from 'jest-fetch-mock'
import { configurationAppointmentsApiService } from '../configuration-api'
import { ListItemModel } from '@reapit/foundations-ts-definitions'
import { mockBrowserSession } from '../__mocks__/session'

const mockedFetch = fetch as FetchMock
const mockConfigurationAppointments = [
  {
    id: 'some_id',
    value: 'some_value',
  },
] as ListItemModel[]

describe('configurationAppointmentsApiService', () => {
  it('should return a response from the config service', () => {
    mockedFetch.mockResponseOnce(JSON.stringify(mockConfigurationAppointments))
    expect(configurationAppointmentsApiService(mockBrowserSession)).toEqual(mockConfigurationAppointments)
  })

  it('should catch an error if no response from config service', () => {
    const errorSpy = jest.spyOn(console, 'error')
    mockedFetch.mockResponseOnce(undefined as any)
    expect(errorSpy).toHaveBeenCalledWith(
      'Error fetching Configuration Appointment Types',
      'No response returned by API',
    )
  })
})
